[GFS2] Rename gfs2_meta_pin to gfs2_pin

Since we'll need to pin data if we are going to journal it, then
I'm renaming this function to make it less confusing. It might also
be worth moving it into lops.c since there are no users outside that
file.

Signed-off-by: Steven Whitehouse <swhiteho@redhat.com>
diff --git a/fs/gfs2/meta_io.c b/fs/gfs2/meta_io.c
index 134f31e..b6bd2eb 100644
--- a/fs/gfs2/meta_io.c
+++ b/fs/gfs2/meta_io.c
@@ -574,13 +574,13 @@
 }
 
 /**
  * gfs2_meta_pin - Pin a metadata buffer in memory
  * @sdp: the filesystem the buffer belongs to
  * @bh: The buffer to be pinned
  *
  */
 
-void gfs2_meta_pin(struct gfs2_sbd *sdp, struct buffer_head *bh)
+void gfs2_pin(struct gfs2_sbd *sdp, struct buffer_head *bh)
 {
 	struct gfs2_bufdata *bd = get_v2bd(bh);
 
@@ -609,15 +609,15 @@
 }
 
 /**
- * gfs2_meta_unpin - Unpin a buffer
+ * gfs2_unpin - Unpin a buffer
  * @sdp: the filesystem the buffer belongs to
  * @bh: The buffer to unpin
  * @ai:
  *
  */
 
-void gfs2_meta_unpin(struct gfs2_sbd *sdp, struct buffer_head *bh,
-		     struct gfs2_ail *ai)
+void gfs2_unpin(struct gfs2_sbd *sdp, struct buffer_head *bh,
+	        struct gfs2_ail *ai)
 {
 	struct gfs2_bufdata *bd = get_v2bd(bh);
@@ -574,13 +574,13 @@
 
 /**
- * gfs2_meta_pin - Pin a metadata buffer in memory
+ * gfs2_pin - Pin a buffer in memory
  * @sdp: the filesystem the buffer belongs to
  * @bh: The buffer to be pinned